# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: systemathics/apis/services/intraday_analytics/v1/intraday_macd.proto
# Protobuf Python Version: 5.27.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    0,
    '',
    'systemathics/apis/services/intraday_analytics/v1/intraday_macd.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import date_interval_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_date__interval__pb2
from systemathics.apis.type.shared.v1 import sampling_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_sampling__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDsystemathics/apis/services/intraday_analytics/v1/intraday_macd.proto\x12\x30systemathics.apis.services.intraday_analytics.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x34systemathics/apis/type/shared/v1/date_interval.proto\x1a/systemathics/apis/type/shared/v1/sampling.proto\"\xca\x02\n\x13IntradayMacdRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x46\n\x08sampling\x18\x02 \x01(\x0e\x32*.systemathics.apis.type.shared.v1.SamplingR\x08sampling\x12S\n\rdate_interval\x18\x03 \x01(\x0b\x32..systemathics.apis.type.shared.v1.DateIntervalR\x0c\x64\x61teInterval\x12\x12\n\x04long\x18\x04 \x01(\x05R\x04long\x12\x14\n\x05short\x18\x05 \x01(\x05R\x05short\x12\x1e\n\nadjustment\x18\x06 \x01(\x08R\nadjustment\"n\n\x14IntradayMacdResponse\x12V\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32\x42.systemathics.apis.services.intraday_analytics.v1.IntradayMacdDataR\x04\x64\x61ta\"\xa1\x01\n\x10IntradayMacdData\x12\x39\n\ntime_stamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimeStamp\x12\x14\n\x05value\x18\x02 \x01(\x01R\x05value\x12\x12\n\x04macd\x18\x03 \x01(\x01R\x04macd\x12\x14\n\x05short\x18\x04 \x01(\x01R\x05short\x12\x12\n\x04long\x18\x05 \x01(\x01R\x04long2\xd0\x01\n\x13IntradayMacdService\x12\xb8\x01\n\x0cIntradayMacd\x12\x45.systemathics.apis.services.intraday_analytics.v1.IntradayMacdRequest\x1a\x46.systemathics.apis.services.intraday_analytics.v1.IntradayMacdResponse\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/v1/intraday/macdB\xaa\x02\n4com.systemathics.apis.services.intraday_analytics.v1B\x11IntradayMacdProtoP\x01\xa2\x02\x04SASI\xaa\x02/Systemathics.Apis.Services.IntradayAnalytics.V1\xca\x02/Systemathics\\Apis\\Services\\IntradayAnalytics\\V1\xe2\x02;Systemathics\\Apis\\Services\\IntradayAnalytics\\V1\\GPBMetadata\xea\x02\x33Systemathics::Apis::Services::IntradayAnalytics::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.intraday_analytics.v1.intraday_macd_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n4com.systemathics.apis.services.intraday_analytics.v1B\021IntradayMacdProtoP\001\242\002\004SASI\252\002/Systemathics.Apis.Services.IntradayAnalytics.V1\312\002/Systemathics\\Apis\\Services\\IntradayAnalytics\\V1\342\002;Systemathics\\Apis\\Services\\IntradayAnalytics\\V1\\GPBMetadata\352\0023Systemathics::Apis::Services::IntradayAnalytics::V1'
  _globals['_INTRADAYMACDSERVICE'].methods_by_name['IntradayMacd']._loaded_options = None
  _globals['_INTRADAYMACDSERVICE'].methods_by_name['IntradayMacd']._serialized_options = b'\202\323\344\223\002\023\022\021/v1/intraday/macd'
  _globals['_INTRADAYMACDREQUEST']._serialized_start=340
  _globals['_INTRADAYMACDREQUEST']._serialized_end=670
  _globals['_INTRADAYMACDRESPONSE']._serialized_start=672
  _globals['_INTRADAYMACDRESPONSE']._serialized_end=782
  _globals['_INTRADAYMACDDATA']._serialized_start=785
  _globals['_INTRADAYMACDDATA']._serialized_end=946
  _globals['_INTRADAYMACDSERVICE']._serialized_start=949
  _globals['_INTRADAYMACDSERVICE']._serialized_end=1157
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: systemathics/apis/services/sustainability/v1/sustainability.proto
# Protobuf Python Version: 5.27.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    0,
    '',
    'systemathics/apis/services/sustainability/v1/sustainability.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAsystemathics/apis/services/sustainability/v1/sustainability.proto\x12,systemathics.apis.services.sustainability.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\"e\n\x15SustainabilityRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\"j\n\x16SustainabilityResponse\x12P\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32<.systemathics.apis.services.sustainability.v1.SustainabilityR\x04\x64\x61ta\"\xc4\x01\n\x0eSustainability\x12\x1a\n\x08provider\x18\x01 \x01(\tR\x08provider\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x0e\n\x02id\x18\x03 \x01(\tR\x02id\x12\x16\n\x06parent\x18\x04 \x01(\tR\x06parent\x12\x14\n\x05value\x18\x05 \x01(\x01R\x05value\x12\x10\n\x03min\x18\x06 \x01(\x01R\x03min\x12\x10\n\x03max\x18\x07 \x01(\x01R\x03max\x12 \n\x0b\x64\x65scription\x18\x08 \x01(\tR\x0b\x64\x65scription2\xd1\x01\n\x15SustainabilityService\x12\xb7\x01\n\x0eSustainability\x12\x43.systemathics.apis.services.sustainability.v1.SustainabilityRequest\x1a\x44.systemathics.apis.services.sustainability.v1.SustainabilityResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\x12\x12/v1/sustainabilityB\x9c\x02\n0com.systemathics.apis.services.sustainability.v1B\x13SustainabilityProtoP\x01\xa2\x02\x04SASS\xaa\x02,Systemathics.Apis.Services.Sustainability.V1\xca\x02,Systemathics\\Apis\\Services\\Sustainability\\V1\xe2\x02\x38Systemathics\\Apis\\Services\\Sustainability\\V1\\GPBMetadata\xea\x02\x30Systemathics::Apis::Services::Sustainability::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.sustainability.v1.sustainability_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n0com.systemathics.apis.services.sustainability.v1B\023SustainabilityProtoP\001\242\002\004SASS\252\002,Systemathics.Apis.Services.Sustainability.V1\312\002,Systemathics\\Apis\\Services\\Sustainability\\V1\342\0028Systemathics\\Apis\\Services\\Sustainability\\V1\\GPBMetadata\352\0020Systemathics::Apis::Services::Sustainability::V1'
  _globals['_SUSTAINABILITYSERVICE'].methods_by_name['Sustainability']._loaded_options = None
  _globals['_SUSTAINABILITYSERVICE'].methods_by_name['Sustainability']._serialized_options = b'\202\323\344\223\002\024\022\022/v1/sustainability'
  _globals['_SUSTAINABILITYREQUEST']._serialized_start=196
  _globals['_SUSTAINABILITYREQUEST']._serialized_end=297
  _globals['_SUSTAINABILITYRESPONSE']._serialized_start=299
  _globals['_SUSTAINABILITYRESPONSE']._serialized_end=405
  _globals['_SUSTAINABILITY']._serialized_start=408
  _globals['_SUSTAINABILITY']._serialized_end=604
  _globals['_SUSTAINABILITYSERVICE']._serialized_start=607
  _globals['_SUSTAINABILITYSERVICE']._serialized_end=816
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: systemathics/apis/services/daily/v1/daily_vwap.proto
# Protobuf Python Version: 5.27.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    0,
    '',
    'systemathics/apis/services/daily/v1/daily_vwap.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.type import date_pb2 as google_dot_type_dot_date__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import date_interval_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_date__interval__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4systemathics/apis/services/daily/v1/daily_vwap.proto\x12#systemathics.apis.services.daily.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x16google/type/date.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x34systemathics/apis/type/shared/v1/date_interval.proto\"\xd6\x01\n\x11\x44\x61ilyVwapsRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12S\n\rdate_interval\x18\x02 \x01(\x0b\x32..systemathics.apis.type.shared.v1.DateIntervalR\x0c\x64\x61teInterval\x12\x1e\n\nadjustment\x18\x03 \x01(\x08R\nadjustment\"X\n\x12\x44\x61ilyVwapsResponse\x12\x42\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32..systemathics.apis.services.daily.v1.DailyVwapR\x04\x64\x61ta\"v\n\tDailyVwap\x12%\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x11.google.type.DateR\x04\x64\x61te\x12\x14\n\x05price\x18\x02 \x01(\x01R\x05price\x12\x16\n\x06volume\x18\x03 \x01(\x01R\x06volume\x12\x14\n\x05score\x18\x04 \x01(\x01R\x05score2\xac\x01\n\x11\x44\x61ilyVwapsService\x12\x96\x01\n\nDailyVwaps\x12\x36.systemathics.apis.services.daily.v1.DailyVwapsRequest\x1a\x37.systemathics.apis.services.daily.v1.DailyVwapsResponse\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/v1/daily/vwapsB\xea\x01\n\'com.systemathics.apis.services.daily.v1B\x0e\x44\x61ilyVwapProtoP\x01\xa2\x02\x04SASD\xaa\x02#Systemathics.Apis.Services.Daily.V1\xca\x02#Systemathics\\Apis\\Services\\Daily\\V1\xe2\x02/Systemathics\\Apis\\Services\\Daily\\V1\\GPBMetadata\xea\x02\'Systemathics::Apis::Services::Daily::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.daily.v1.daily_vwap_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\'com.systemathics.apis.services.daily.v1B\016DailyVwapProtoP\001\242\002\004SASD\252\002#Systemathics.Apis.Services.Daily.V1\312\002#Systemathics\\Apis\\Services\\Daily\\V1\342\002/Systemathics\\Apis\\Services\\Daily\\V1\\GPBMetadata\352\002\'Systemathics::Apis::Services::Daily::V1'
  _globals['_DAILYVWAPSSERVICE'].methods_by_name['DailyVwaps']._loaded_options = None
  _globals['_DAILYVWAPSSERVICE'].methods_by_name['DailyVwaps']._serialized_options = b'\202\323\344\223\002\021\022\017/v1/daily/vwaps'
  _globals['_DAILYVWAPSREQUEST']._serialized_start=253
  _globals['_DAILYVWAPSREQUEST']._serialized_end=467
  _globals['_DAILYVWAPSRESPONSE']._serialized_start=469
  _globals['_DAILYVWAPSRESPONSE']._serialized_end=557
  _globals['_DAILYVWAP']._serialized_start=559
  _globals['_DAILYVWAP']._serialized_end=677
  _globals['_DAILYVWAPSSERVICE']._serialized_start=680
  _globals['_DAILYVWAPSSERVICE']._serialized_end=852
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: systemathics/apis/services/intraday/v1/intraday_market_data.proto
# Protobuf Python Version: 5.27.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    0,
    '',
    'systemathics/apis/services/intraday/v1/intraday_market_data.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import date_interval_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_date__interval__pb2
from systemathics.apis.type.shared.v1 import sampling_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_sampling__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAsystemathics/apis/services/intraday/v1/intraday_market_data.proto\x12&systemathics.apis.services.intraday.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x34systemathics/apis/type/shared/v1/date_interval.proto\x1a/systemathics/apis/type/shared/v1/sampling.proto\"\x86\x02\n\x19IntradayMarketDataRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x46\n\x08sampling\x18\x02 \x01(\x0e\x32*.systemathics.apis.type.shared.v1.SamplingR\x08sampling\x12S\n\rdate_interval\x18\x03 \x01(\x0b\x32..systemathics.apis.type.shared.v1.DateIntervalR\x0c\x64\x61teInterval\"l\n\x1aIntradayMarketDataResponse\x12N\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32:.systemathics.apis.services.intraday.v1.IntradayMarketDataR\x04\x64\x61ta\"\x99\x04\n\x12IntradayMarketData\x12\x39\n\ntime_stamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimeStamp\x12\x12\n\x04open\x18\x02 \x01(\x01R\x04open\x12\x12\n\x04high\x18\x03 \x01(\x01R\x04high\x12\x10\n\x03low\x18\x04 \x01(\x01R\x03low\x12\x14\n\x05\x63lose\x18\x05 \x01(\x01R\x05\x63lose\x12\x16\n\x06volume\x18\x06 \x01(\x01R\x06volume\x12\x1b\n\tbid_price\x18\x07 \x01(\x01R\x08\x62idPrice\x12\x19\n\x08\x62id_size\x18\x08 \x01(\x01R\x07\x62idSize\x12\x1b\n\task_price\x18\t \x01(\x01R\x08\x61skPrice\x12\x19\n\x08\x61sk_size\x18\n \x01(\x01R\x07\x61skSize\x12\x14\n\x05\x64\x65lta\x18\x0b \x01(\x01R\x05\x64\x65lta\x12\x14\n\x05gamma\x18\x0c \x01(\x01R\x05gamma\x12\x14\n\x05theta\x18\r \x01(\x01R\x05theta\x12\x12\n\x04vega\x18\x0e \x01(\x01R\x04vega\x12\x10\n\x03rho\x18\x0f \x01(\x01R\x03rho\x12-\n\x12implied_volatility\x18\x10 \x01(\x01R\x11impliedVolatility\x12#\n\ropen_interest\x18\x11 \x01(\x01R\x0copenInterest\x12\x1e\n\nunderlying\x18\x12 \x01(\x01R\nunderlying\x12\x14\n\x05score\x18\x13 \x01(\x01R\x05score2\xda\x01\n\x19IntradayMarketDataService\x12\xbc\x01\n\x12IntradayMarketData\x12\x41.systemathics.apis.services.intraday.v1.IntradayMarketDataRequest\x1a\x42.systemathics.apis.services.intraday.v1.IntradayMarketDataResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/v1/intraday/marketdataB\x82\x02\n*com.systemathics.apis.services.intraday.v1B\x17IntradayMarketDataProtoP\x01\xa2\x02\x04SASI\xaa\x02&Systemathics.Apis.Services.Intraday.V1\xca\x02&Systemathics\\Apis\\Services\\Intraday\\V1\xe2\x02\x32Systemathics\\Apis\\Services\\Intraday\\V1\\GPBMetadata\xea\x02*Systemathics::Apis::Services::Intraday::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.intraday.v1.intraday_market_data_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n*com.systemathics.apis.services.intraday.v1B\027IntradayMarketDataProtoP\001\242\002\004SASI\252\002&Systemathics.Apis.Services.Intraday.V1\312\002&Systemathics\\Apis\\Services\\Intraday\\V1\342\0022Systemathics\\Apis\\Services\\Intraday\\V1\\GPBMetadata\352\002*Systemathics::Apis::Services::Intraday::V1'
  _globals['_INTRADAYMARKETDATASERVICE'].methods_by_name['IntradayMarketData']._loaded_options = None
  _globals['_INTRADAYMARKETDATASERVICE'].methods_by_name['IntradayMarketData']._serialized_options = b'\202\323\344\223\002\031\022\027/v1/intraday/marketdata'
  _globals['_INTRADAYMARKETDATAREQUEST']._serialized_start=327
  _globals['_INTRADAYMARKETDATAREQUEST']._serialized_end=589
  _globals['_INTRADAYMARKETDATARESPONSE']._serialized_start=591
  _globals['_INTRADAYMARKETDATARESPONSE']._serialized_end=699
  _globals['_INTRADAYMARKETDATA']._serialized_start=702
  _globals['_INTRADAYMARKETDATA']._serialized_end=1239
  _globals['_INTRADAYMARKETDATASERVICE']._serialized_start=1242
  _globals['_INTRADAYMARKETDATASERVICE']._serialized_end=1460
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from systemathics.apis.services.daily.v1 import daily_calendars_pb2 as systemathics_dot_apis_dot_services_dot_daily_dot_v1_dot_daily__calendars__pb2


class DailyCalendarsServiceStub(object):
    """Called to request daily calendars data. 
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.DailyCalendars = channel.unary_unary(
                '/systemathics.apis.services.daily.v1.DailyCalendarsService/DailyCalendars',
                request_serializer=systemathics_dot_apis_dot_services_dot_daily_dot_v1_dot_daily__calendars__pb2.DailyCalendarsRequest.SerializeToString,
                response_deserializer=systemathics_dot_apis_dot_services_dot_daily_dot_v1_dot_daily__calendars__pb2.DailyCalendarsResponse.FromString,
                )


class DailyCalendarsServiceServicer(object):
    """Called to request daily calendars data. 
    """

    def DailyCalendars(self, request, context):
        """Gets daily historical calendars
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DailyCalendarsServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'DailyCalendars': grpc.unary_unary_rpc_method_handler(
                    servicer.DailyCalendars,
                    request_deserializer=systemathics_dot_apis_dot_services_dot_daily_dot_v1_dot_daily__calendars__pb2.DailyCalendarsRequest.FromString,
                    response_serializer=systemathics_dot_apis_dot_services_dot_daily_dot_v1_dot_daily__calendars__pb2.DailyCalendarsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'systemathics.apis.services.daily.v1.DailyCalendarsService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DailyCalendarsService(object):
    """Called to request daily calendars data. 
    """

    @staticmethod
    def DailyCalendars(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/systemathics.apis.services.daily.v1.DailyCalendarsService/DailyCalendars',
            systemathics_dot_apis_dot_services_dot_daily_dot_v1_dot_daily__calendars__pb2.DailyCalendarsRequest.SerializeToString,
            systemathics_dot_apis_dot_services_dot_daily_dot_v1_dot_daily__calendars__pb2.DailyCalendarsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
